@@ -18,10 +18,12 @@ EXCEPT = "#"
 REGEX = "$"
 IGNORE = "!"
 RECURSION = "&"
+ANYTHING = "1"
+
 
 # Constants
 
-SYNTAX_CHARS: Tuple[str, ...] = (UNION, ONE_CHAR, EXCEPT, REGEX, IGNORE, RECURSION)
+SYNTAX_CHARS: Tuple[str, ...] = (UNION, ONE_CHAR, EXCEPT, REGEX, IGNORE, RECURSION, ANYTHING)
 ESCAPE = {ord(x): "\\" + x for x in r"\.*+?()[]|^${}&"}
 
 # Regex patterns
